@@ -1441,6 +1441,10 @@ Overwrite?</source>
         <source>144 kbps</source>
         <translation>144 kbps</translation>
     </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
 </context>
 <context>
     <name>RDGetAth</name>
