@@ -407,6 +407,22 @@
         <source>Previous</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Classical Music Playout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>reserved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mr. Master Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Spin Count</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -519,7 +535,7 @@
     </message>
     <message>
         <source>The name is invalid!</source>
-        <translation>O Nome é Inválido!</translation>
+        <translation type="obsolete">O Nome é Inválido!</translation>
     </message>
     <message>
         <source>The service is invalid!</source>
@@ -826,6 +842,10 @@ Cor</translation>
         <source>End</source>
         <translation type="unfinished">Fim</translation>
     </message>
+    <message>
+        <source>&amp;Recue</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDCueEditDialog</name>
@@ -1425,6 +1445,10 @@ Sobreescrever?</translation>
         <source>144 kbps</source>
         <translation>144 kbps</translation>
     </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
 </context>
 <context>
     <name>RDGetAth</name>
