@@ -561,6 +561,11 @@
 #define RDCARTSLOTS_MAX_ROWS 16
 #define RDCARTSLOTS_MAX_COLUMNS 4
 
+/*
+ * RDLogEdit Log Listing Limit Quantity
+ */
+#define RDLOGEDIT_LIMIT_QUAN 14
+
 /*
  * Custom MIME Types (for Drag and Drop)
  */
