@@ -1,10 +1,8 @@
 //   rdwavefile.cpp
 //
-//   A class for handling Microsoft WAV files.
+//   A class for handling audio files.
 //
-//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdwavefile.cpp,v 1.24.6.5.2.3 2014/07/15 20:02:23 cvs Exp $
+//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -33,6 +31,7 @@
 #include <arpa/inet.h>
 #include <unistd.h>
 #include <errno.h>
+#include <assert.h>
 
 #include <id3/tag.h>
 #include <id3/misc_support.h>
@@ -47,6 +46,11 @@
 #include <rd.h>
 #include <rdwavefile.h>
 #include <rdconf.h>
+#include <rdmp4.h>
+
+#ifdef HAVE_MP4_LIBS
+#include <mp4v2/mp4v2.h>
+#endif
 
 RDWaveFile::RDWaveFile(QString file_name)
 {
@@ -162,7 +166,6 @@ RDWaveFile::RDWaveFile(QString file_name)
   levl_block_size=DEFAULT_LEVL_BLOCK_SIZE;
   cook_buffer=NULL;
   cook_buffer_size=0;
-  cook_encoding=RDWaveFile::Raw;
   wave_type=RDWaveFile::Unknown;
   encode_quality=5.0f;
   serial_number=-1;
@@ -322,6 +325,75 @@ bool RDWaveFile::openWave(RDWaveData *data)
     ReadId3Metadata();
     break;
 
+  case RDWaveFile::M4A:
+    {
+#ifdef HAVE_MP4_LIBS   
+
+      // MP4 libs must already be loaded by now for file to have that type.
+      assert(dlmp4.load());
+      format_tag=WAVE_FORMAT_M4A;
+
+      MP4FileHandle f = dlmp4.MP4Read(getName());
+      if(f == MP4_INVALID_FILE_HANDLE)
+	return false;
+
+      // Find an audio track, and populate sample rate, bits/sample etc.
+      MP4TrackId audioTrack = dlmp4.getMP4AACTrack(f);
+
+      if(audioTrack == MP4_INVALID_TRACK_ID) {
+	dlmp4.MP4Close(f, 0);
+	return false;
+      }
+
+      // Found audio track. Get audio data:
+      avg_bytes_per_sec = dlmp4.MP4GetTrackBitRate(f, audioTrack);
+      channels = dlmp4.MP4GetTrackAudioChannels(f, audioTrack);
+
+      MP4Duration trackDuration = dlmp4.MP4GetTrackDuration(f, audioTrack);
+      ext_time_length = (unsigned)dlmp4.MP4ConvertFromTrackDuration(f, audioTrack, trackDuration, 
+								    MP4_MSECS_TIME_SCALE);
+      time_length = ext_time_length / 1000;
+      samples_per_sec = dlmp4.MP4GetTrackTimeScale(f, audioTrack);
+      bits_per_sample = 16;
+      data_start = 0;
+      sample_length = dlmp4.MP4GetTrackNumberOfSamples(f, audioTrack);
+      data_length = sample_length * 2 * channels;
+      data_chunk = true;
+      format_chunk = true;
+      wave_type = RDWaveFile::M4A;
+
+      // Now extract metadata (title, artist, etc)
+
+      if(wave_data) {
+
+	const MP4Tags* tags = dlmp4.MP4TagsAlloc();
+	dlmp4.MP4TagsFetch(tags, f);
+	
+	wave_data->setMetadataFound(true);
+	
+	if(tags->name)
+	  wave_data->setTitle(tags->name);
+	if(tags->artist)
+	  wave_data->setArtist(tags->artist);
+	if(tags->composer)
+	  wave_data->setComposer(tags->composer);
+	if(tags->album)
+	  wave_data->setAlbum(tags->album);
+
+	dlmp4.MP4TagsFree(tags);
+
+      }
+
+      dlmp4.MP4Close(f, 0);
+
+      return true;
+
+#else
+      return false;
+#endif
+      break;
+    }
+
   case RDWaveFile::Ogg:
 #ifdef HAVE_VORBIS
     format_tag=WAVE_FORMAT_VORBIS;
@@ -800,7 +872,6 @@ void RDWaveFile::closeWave(int samples)
   free(cook_buffer);
   cook_buffer=NULL;
   cook_buffer_size=0;
-  cook_encoding=RDWaveFile::Raw;
   encode_quality=5.0f;
   serial_number=-1;
   atx_offset=0;
@@ -869,18 +940,6 @@ unsigned RDWaveFile::getDataLength() const
 }
 
 
-RDWaveFile::Encoding RDWaveFile::encoding() const
-{
-  return cook_encoding;
-}
-
-
-void RDWaveFile::setEncoding(RDWaveFile::Encoding code)
-{
-  cook_encoding=code;
-}
-
-
 int RDWaveFile::readWave(void *buf,int count)
 {
   int stream;
@@ -944,115 +1003,182 @@ int RDWaveFile::writeWave(void *buf,int count)
     return -1;
   }
   switch(format_tag) {
-      case WAVE_FORMAT_PCM:
-	if(levl_chunk) {
-	  for(int i=0;i<count;i++) {
-	    switch(levl_istate) {
-		case 0:   // Left Channel, LSB
-		  levl_accum=((char *)buf)[i]&0xff;
-		  levl_istate=1;
-		  break;
+  case WAVE_FORMAT_PCM:
+    switch(bits_per_sample) {
+    case 16:
+      if(levl_chunk) {
+	for(int i=0;i<count;i++) {
+	  switch(levl_istate) {
+	  case 0:   // Left Channel, LSB
+	    levl_accum=((char *)buf)[i]&0xff;
+	    levl_istate=1;
+	    break;
 
-		case 1:   // Left Channel, MSB
-		  levl_accum|=((((char *)buf)[i]&0xff)<<8);
-		  switch(channels) {
-		      case 1:
-			if(levl_accum>energy_data[energy_data.size()-1]) {
-			  energy_data[energy_data.size()-1]=levl_accum;
-			}
-			if(++levl_block_ptr==1152) {
-			  energy_data.push_back(0);
-			  levl_block_ptr=0;
-			}
-			levl_istate=0;
-			break;
-
-		      case 2:
-			if(levl_accum>energy_data[energy_data.size()-2]) {
-			  energy_data[energy_data.size()-2]=levl_accum;
-			}
-			levl_istate=2;
-			break;
-		  }
-		  break;
-
-		case 2:   // Right Channel, LSB
-		  levl_accum=((char *)buf)[i]&0xff;
-		  levl_istate=3;
-		  break;
-
-		case 3:   // Right Channel, MSB
-		  levl_accum|=((((char *)buf)[i]&0xff)<<8);
-		  if(levl_accum>energy_data[energy_data.size()-1]) {
-		    energy_data[energy_data.size()-1]=levl_accum;
-		  }
-		  if(++levl_block_ptr==1152) {
-		    energy_data.push_back(0);
-		    energy_data.push_back(0);
-		    levl_block_ptr=0;
-		  }
-		  levl_istate=0;
-		  break;
-	    }
-	  }
-	}
-	lseek(wave_file.handle(),0,SEEK_END);
-	data_length+=count;
-	// Fixup the buffer for big endian hosts (Wav is defined as LE).
-	if (htonl (1l) == 1l){ // Big endian host
-	  for(int i = 0; i < count/2; i++) {
-	    unsigned short s = ((unsigned short*)buf)[i];
-	    WriteSword((unsigned char *)buf,2*i,s);
-	  }
-	}
-	return write(wave_file.handle(),buf,count);
-
-      case WAVE_FORMAT_MPEG:
-	if(levl_chunk&&(head_layer==2)) {
-	  for(int i=0;i<count;i++) {
-	    if(levl_block_ptr==(block_align-5)) {  // Right Channel, MSB
-	      if(channels==2) {
-		levl_accum=((((char *)buf)[i]&0xff)<<8);
+	  case 1:   // Left Channel, MSB
+	    levl_accum|=((((char *)buf)[i]&0xff)<<8);
+	    switch(channels) {
+	    case 1:
+	      if(levl_accum>energy_data[energy_data.size()-1]) {
+		energy_data[energy_data.size()-1]=levl_accum;
 	      }
+	      if(++levl_block_ptr==1152) {
+		energy_data.push_back(0);
+		levl_block_ptr=0;
+	      }
+	      levl_istate=0;
+	      break;
+
+	    case 2:
+	      if(levl_accum>energy_data[energy_data.size()-2]) {
+		energy_data[energy_data.size()-2]=levl_accum;
+	      }
+	      levl_istate=2;
+	      break;
+	    }
+	    break;
+
+	  case 2:   // Right Channel, LSB
+	    levl_accum=((char *)buf)[i]&0xff;
+	    levl_istate=3;
+	    break;
+
+	  case 3:   // Right Channel, MSB
+	    levl_accum|=((((char *)buf)[i]&0xff)<<8);
+	    if(levl_accum>energy_data[energy_data.size()-1]) {
+	      energy_data[energy_data.size()-1]=levl_accum;
+	    }
+	    if(++levl_block_ptr==1152) {
+	      energy_data.push_back(0);
+	      energy_data.push_back(0);
+	      levl_block_ptr=0;
+	    }
+	    levl_istate=0;
+	    break;
+	  }
+	}
+      }
+      lseek(wave_file.handle(),0,SEEK_END);
+      data_length+=count;
+      // Fixup the buffer for big endian hosts (Wav is defined as LE).
+      if (htonl (1l) == 1l){ // Big endian host
+	for(int i = 0; i < count/2; i++) {
+	  unsigned short s = ((unsigned short*)buf)[i];
+	  WriteSword((unsigned char *)buf,2*i,s);
+	}
+      }
+      return write(wave_file.handle(),buf,count);
+
+    case 24:
+      if(levl_chunk) {
+	for(int i=0;i<count;i++) {
+	  switch(levl_istate) {
+	  case 0:   // Left Channel LSB
+	    levl_istate=1;
+	    break;
+
+	  case 1:   // Left Channel, Middle Byte
+	    levl_accum=((char *)buf)[i]&0xff;
+	    levl_istate=2;
+	    break;
+
+	  case 2:   // Left Channel, MSB
+	    levl_accum|=((((char *)buf)[i]&0xff)<<8);
+	    switch(channels) {
+	    case 1:
+	      if(levl_accum>energy_data[energy_data.size()-1]) {
+		energy_data[energy_data.size()-1]=levl_accum;
+	      }
+	      if(++levl_block_ptr==1152) {
+		energy_data.push_back(0);
+		levl_block_ptr=0;
+	      }
+	      levl_istate=0;
+	      break;
+
+	    case 2:
+	      if(levl_accum>energy_data[energy_data.size()-2]) {
+		energy_data[energy_data.size()-2]=levl_accum;
+	      }
+	      levl_istate=3;
+	      break;
+	    }
+	    break;
+
+	  case 3:  // Right Channel, LSB
+	    levl_istate=4;
+	    break;
+
+	  case 4:   // Right Channel, Middle
+	    levl_accum=((char *)buf)[i]&0xff;
+	    levl_istate=5;
+	    break;
+
+	  case 5:   // Right Channel, MSB
+	    levl_accum|=((((char *)buf)[i]&0xff)<<8);
+	    if(levl_accum>energy_data[energy_data.size()-1]) {
+	      energy_data[energy_data.size()-1]=levl_accum;
+	    }
+	    if(++levl_block_ptr==1152) {
+	      energy_data.push_back(0);
+	      energy_data.push_back(0);
+	      levl_block_ptr=0;
+	    }
+	    levl_istate=0;
+	    break;
+	  }
+	}
+      }
+      lseek(wave_file.handle(),0,SEEK_END);
+      data_length+=count;
+      return write(wave_file.handle(),buf,count);
+    }
+
+  case WAVE_FORMAT_MPEG:
+    if(levl_chunk&&(head_layer==2)) {
+      for(int i=0;i<count;i++) {
+	if(levl_block_ptr==(block_align-5)) {  // Right Channel, MSB
+	  if(channels==2) {
+	    levl_accum=((((char *)buf)[i]&0xff)<<8);
+	  }
+	  levl_block_ptr++;
+	}
+	else {
+	  if(levl_block_ptr==(block_align-4)) {  // Right Channel, LSB
+	    if(channels==2) {
+	      levl_accum|=((char *)buf)[i]&0xff;
+	      energy_data[energy_data.size()-1]=levl_accum;
+	    }
+	    levl_block_ptr++;
+	  }
+	  else {
+	    if(levl_block_ptr==(block_align-2)) { // Left Channel, MSB
+	      levl_accum=((((char *)buf)[i]&0xff)<<8);
 	      levl_block_ptr++;
 	    }
 	    else {
-	      if(levl_block_ptr==(block_align-4)) {  // Right Channel, LSB
-		if(channels==2) {
-		  levl_accum|=((char *)buf)[i]&0xff;
-		  energy_data[energy_data.size()-1]=levl_accum;
+	      if(levl_block_ptr==(block_align-1)) {  // Left Channel, LSB
+		levl_accum|=((char *)buf)[i]&0xff;
+		energy_data[energy_data.size()-channels]=levl_accum;
+		for(unsigned j=0;j<channels;j++) {
+		  energy_data.push_back(0);
 		}
-		levl_block_ptr++;
+		levl_block_ptr=0;
 	      }
 	      else {
-		if(levl_block_ptr==(block_align-2)) { // Left Channel, MSB
-		  levl_accum=((((char *)buf)[i]&0xff)<<8);
-		  levl_block_ptr++;
-		}
-		else {
-		  if(levl_block_ptr==(block_align-1)) {  // Left Channel, LSB
-		    levl_accum|=((char *)buf)[i]&0xff;
-		    energy_data[energy_data.size()-channels]=levl_accum;
-		    for(unsigned j=0;j<channels;j++) {
-		      energy_data.push_back(0);
-		    }
-		    levl_block_ptr=0;
-		  }
-		  else {
-		    levl_block_ptr++;
-		  }
-		}
+		levl_block_ptr++;
 	      }
 	    }
 	  }
 	}
-	lseek(wave_file.handle(),0,SEEK_END);
-	data_length+=count;
-	return write(wave_file.handle(),buf,count);
+      }
+    }
+    lseek(wave_file.handle(),0,SEEK_END);
+    data_length+=count;
+    return write(wave_file.handle(),buf,count);
 
-      case WAVE_FORMAT_VORBIS:
-	WriteOggBuffer((char *)buf,count);
-	break;
+  case WAVE_FORMAT_VORBIS:
+    WriteOggBuffer((char *)buf,count);
+    break;
   }
   return 0;
 }
@@ -2020,6 +2146,9 @@ RDWaveFile::Type RDWaveFile::GetType(int fd)
   if(IsOgg(fd)) {
     return RDWaveFile::Ogg;
   }
+  if(IsM4A(fd)) {
+    return RDWaveFile::M4A;
+  }
   if(IsMpeg(fd)) {
     return RDWaveFile::Mpeg;
   }
@@ -2211,6 +2340,20 @@ bool RDWaveFile::IsAiff(int fd)
   return true;
 }
 
+bool RDWaveFile::IsM4A(int fd)
+{
+#ifdef HAVE_MP4_LIBS
+  if(!dlmp4.load())
+    return false;
+  MP4FileHandle f = dlmp4.MP4Read(getName());
+  bool ret = f != MP4_INVALID_FILE_HANDLE;
+  if(ret)
+    dlmp4.MP4Close(f, 0);
+  return ret;
+#else
+  return false;
+#endif
+}
 
 off_t RDWaveFile::FindChunk(int fd,const char *chunk_name,unsigned *chunk_size,
 			    bool big_end)
@@ -4095,7 +4238,7 @@ bool RDWaveFile::MakeLevl()
   WriteDword(levl_chunk_data,16,levl_channels);    // Channels
   WriteDword(levl_chunk_data,20,levl_frames);      // Total Peak Values
   WriteDword(levl_chunk_data,24,levl_peak_offset); // Offset to Peak-of-Peaks
-  WriteDword(levl_chunk_data,28,128);              // Offset to Peak Data
+  WriteDword(levl_chunk_data,28,132);              // Offset to Peak Data
   sprintf((char *)levl_chunk_data+32,"%s",
 	  (const char *)levl_timestamp.toString("yyyy:MM:dd:hh:mm:ss:000"));
 
@@ -4231,81 +4374,106 @@ unsigned RDWaveFile::LoadEnergy()
   energy_size=getSampleLength()*getChannels()/1152;
   seekWave(0,SEEK_SET);
   switch(format_tag) {
-      case WAVE_FORMAT_MPEG:
-	if((head_layer==2)&&(mext_left_energy||mext_right_energy)) {
-	  while(i<energy_size) {
-	    lseek(wave_file.handle(),block_align-5,SEEK_CUR);
-	    if(read(wave_file.handle(),block,5)<5) {
-	      has_energy=true;
-	      return i;
-	    }
-	    if(mext_left_energy) {
-	      energy_data.push_back(block[4]+256*block[3]);
-	      i++;
-	    }
-	    if(mext_right_energy) {
-	      energy_data.push_back(block[1]+256*block[0]);
-	      i++;
-	    }
-	  }
+  case WAVE_FORMAT_MPEG:
+    if((head_layer==2)&&(mext_left_energy||mext_right_energy)) {
+      while(i<energy_size) {
+	lseek(wave_file.handle(),block_align-5,SEEK_CUR);
+	if(read(wave_file.handle(),block,5)<5) {
 	  has_energy=true;
 	  return i;
 	}
-	else {
-	  has_energy=false;
-	  return 0;
+	if(mext_left_energy) {
+	  energy_data.push_back(block[4]+256*block[3]);
+	  i++;
 	}
-	break;
+	if(mext_right_energy) {
+	  energy_data.push_back(block[1]+256*block[0]);
+	  i++;
+	}
+      }
+      has_energy=true;
+      return i;
+    }
+    else {
+      has_energy=false;
+      return 0;
+    }
+    break;
 
-      case WAVE_FORMAT_PCM:
-	block_size=2304*channels;
-	while(i<energy_size) {
-	  if(read(wave_file.handle(),pcm,block_size)!=block_size) {
-	    has_energy=true;
-	    return i;
-	  }
-	  for(int j=0;j<channels;j++) {
-	    energy_data.push_back(0);
-	    for(int k=0;k<1152;k++) {
-	      offset=2*k*channels+2*j;
-	      if((pcm[offset]+256*pcm[offset+1])>energy_data[i]) {
-		energy_data[i]=pcm[offset]+256*pcm[offset+1];
-	      }
-	    }
-	    i++;
-	  }
+  case WAVE_FORMAT_PCM:
+    switch(bits_per_sample) {
+    case 16:
+      block_size=2304*channels;
+      while(i<energy_size) {
+	if(read(wave_file.handle(),pcm,block_size)!=block_size) {
+	  has_energy=true;
+	  return i;
 	}
+	for(int j=0;j<channels;j++) {
+	  energy_data.push_back(0);
+	  for(int k=0;k<1152;k++) {
+	    offset=2*k*channels+2*j;
+	    if((pcm[offset]+256*pcm[offset+1])>energy_data[i]) {
+	      energy_data[i]=pcm[offset]+256*pcm[offset+1];
+	    }
+	  }
+	  i++;
+	}
+      }
+      has_energy=true;
+      return i;
+
+    case 24:
+      block_size=3456*channels;
+      while(i<energy_size) {
+	if(read(wave_file.handle(),pcm,block_size)!=block_size) {
+	  has_energy=true;
+	  return i;
+	}
+	for(int j=0;j<channels;j++) {
+	  energy_data.push_back(0);
+	  for(int k=0;k<1152;k++) {
+	    offset=3*k*channels+3*j;
+	    if((pcm[offset]+256*pcm[offset+1])>energy_data[i]) {
+	      energy_data[i]=pcm[offset]+256*pcm[offset+1];
+	    }
+	  }
+	  i++;
+	}
+      }
+      has_energy=true;
+      return i;
+    }
+    break;
+
+  case WAVE_FORMAT_VORBIS:
+    block_size=2304*channels;
+    while(i<energy_size) {
+      if(readWave(pcm,block_size)!=block_size) {
 	has_energy=true;
 	return i;
-	break;
-
-      case WAVE_FORMAT_VORBIS:
-	block_size=2304*channels;
-	while(i<energy_size) {
-	  if(readWave(pcm,block_size)!=block_size) {
-	    has_energy=true;
-	    return i;
-	  }
-	  for(int j=0;j<channels;j++) {
-	    energy_data.push_back(0);
-	    for(int k=0;k<1152;k++) {
-	      offset=2*k*channels+2*j;
-	      if((pcm[offset]+256*pcm[offset+1])>energy_data[i]) {
-		energy_data[i]=pcm[offset]+256*pcm[offset+1];
-	      }
-	    }
-	    i++;
+      }
+      for(int j=0;j<channels;j++) {
+	energy_data.push_back(0);
+	for(int k=0;k<1152;k++) {
+	  offset=2*k*channels+2*j;
+	  if((pcm[offset]+256*pcm[offset+1])>energy_data[i]) {
+	    energy_data[i]=pcm[offset]+256*pcm[offset+1];
 	  }
 	}
-	has_energy=true;
-	return i;
-	break;
+	i++;
+      }
+    }
+    has_energy=true;
+    return i;
+    break;
 
-      default:
-	has_energy=false;
-	return 0;
-	break;
+  default:
+    has_energy=false;
+    return 0;
+    break;
   }
+  return 0;
 }
 
 
