@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_download.cpp,v 1.12 2007/09/14 14:06:49 fredg Exp $
+//      $Id: edit_download.cpp,v 1.20 2011/08/30 23:35:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,11 +29,10 @@
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <qsqldatabase.h>
 #include <qurl.h>
 
 #include <rdurl.h>
-
+#include <rddb.h>
 #include <rd.h>
 #include <rdcut_dialog.h>
 #include <rdcut_path.h>
@@ -45,11 +44,11 @@
 
 
 EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
-			   QString *group,QWidget *parent,const char *name)
+			   QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString temp;
 
   //
@@ -70,10 +69,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   QFont day_font=QFont("Helvetica",10,QFont::Normal);
   day_font.setPixelSize(10);
 
-  edit_filter=filter;
-  edit_group=group;
   edit_deck=NULL;
   edit_added_events=adds;
+  edit_filter=filter;
 
   setCaption(tr("Edit Download"));
 
@@ -253,11 +251,22 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_normalize_unit->setFont(label_font);
   edit_normalize_unit->setAlignment(AlignVCenter|AlignLeft);
 
+  //
+  // Export Metadata Box
+  //
+  edit_metadata_box=new QCheckBox(this,"edit_metadata_box");
+  edit_metadata_box->setGeometry(120,222,15,15);
+  label=new QLabel(edit_metadata_box,tr("Update Library Metadata"),
+		   this,"metadata_check_label");
+  label->setGeometry(140,222,160,20);
+  label->setFont(label_font);
+  label->setAlignment(AlignLeft|AlignVCenter);
+
   //
   // Button Label
   //
   label=new QLabel(tr("Active Days"),this,"active_days_label");
-  label->setGeometry(47,229,90,19);
+  label->setGeometry(47,254,90,19);
   label->setFont(label_font);
   label->setAlignment(AlignHCenter|ShowPrefix);
 
@@ -265,10 +274,10 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   // Monday Button
   //
   edit_mon_button=new QCheckBox(this,"edit_mon_button");
-  edit_mon_button->setGeometry(20,248,20,20);
+  edit_mon_button->setGeometry(20,273,20,20);
   label=new QLabel(edit_mon_button,
 		   tr("Monday"),this,"edit_mon_label");
-  label->setGeometry(40,248,115,20);
+  label->setGeometry(40,273,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -276,10 +285,10 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   // Tuesday Button
   //
   edit_tue_button=new QCheckBox(this,"edit_tue_button");
-  edit_tue_button->setGeometry(115,248,20,20);
+  edit_tue_button->setGeometry(115,273,20,20);
   label=new QLabel(edit_tue_button,
 		   tr("Tuesday"),this,"edit_tue_label");
-  label->setGeometry(135,248,115,20);
+  label->setGeometry(135,273,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -287,10 +296,10 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   // Wednesday Button
   //
   edit_wed_button=new QCheckBox(this,"edit_wed_button");
-  edit_wed_button->setGeometry(215,248,20,20);
+  edit_wed_button->setGeometry(215,273,20,20);
   label=new QLabel(edit_wed_button,
 		   tr("Wednesday"),this,"edit_wed_label");
-  label->setGeometry(235,248,115,20);
+  label->setGeometry(235,273,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -298,10 +307,10 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   // Thursday Button
   //
   edit_thu_button=new QCheckBox(this,"edit_thu_button");
-  edit_thu_button->setGeometry(335,248,20,20);
+  edit_thu_button->setGeometry(335,273,20,20);
   label=new QLabel(edit_thu_button,
 		   tr("Thursday"),this,"edit_thu_label");
-  label->setGeometry(355,248,115,20);
+  label->setGeometry(355,273,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -309,10 +318,10 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   // Friday Button
   //
   edit_fri_button=new QCheckBox(this,"edit_fri_button");
-  edit_fri_button->setGeometry(440,248,20,20);
+  edit_fri_button->setGeometry(440,273,20,20);
   label=new QLabel(edit_fri_button,
 		   tr("Friday"),this,"edit_fri_label");
-  label->setGeometry(460,248,40,20);
+  label->setGeometry(460,273,40,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -320,10 +329,10 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   // Saturday Button
   //
   edit_sat_button=new QCheckBox(this,"edit_sat_button");
-  edit_sat_button->setGeometry(130,273,20,20);
+  edit_sat_button->setGeometry(130,298,20,20);
   label=new QLabel(edit_sat_button,
 		   tr("Saturday"),this,"edit_sat_label");
-  label->setGeometry(150,273,60,20);
+  label->setGeometry(150,298,60,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -331,10 +340,10 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   // Sunday Button
   //
   edit_sun_button=new QCheckBox(this,"edit_sun_button");
-  edit_sun_button->setGeometry(300,273,20,20);
+  edit_sun_button->setGeometry(300,298,20,20);
   label=new QLabel(edit_sun_button,
 		   tr("Sunday"),this,"edit_sun_label");
-  label->setGeometry(320,273,60,20);
+  label->setGeometry(320,298,60,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -342,13 +351,30 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   // OneShot Button
   //
   edit_oneshot_box=new QCheckBox(this,"edit_oneshot_box");
-  edit_oneshot_box->setGeometry(20,308,15,15);
+  edit_oneshot_box->setGeometry(20,335,15,15);
   label=new QLabel(edit_oneshot_box,
 		   tr("Make OneShot"),this,"edit_oneshot_label");
-  label->setGeometry(40,306,115,20);
+  label->setGeometry(40,333,115,20);
   label->setFont(label_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
+  //
+  // Event Offset
+  //
+  edit_eventoffset_spin=new QSpinBox(this,"edit_eventoffset_spin");
+  edit_eventoffset_spin->setGeometry(245,333,45,20);
+  edit_eventoffset_spin->setRange(-30,30);
+  label=new QLabel(edit_eventoffset_spin,tr("Event Offset:"),
+		   this,"edit_eventoffset_label");
+  label->setGeometry(140,333,100,20);
+  label->setFont(label_font);
+  label->setAlignment(AlignVCenter|AlignRight);
+  label=new QLabel(edit_eventoffset_spin,tr("days"),
+		   this,"edit_eventoffset_unit");
+  label->setGeometry(295,333,40,20);
+  label->setFont(label_font);
+  label->setAlignment(AlignVCenter|AlignLeft);
+
   //
   //  Save As Button
   //
@@ -383,7 +409,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Populate Data
   //
-  q=new QSqlQuery("select NAME from STATIONS where NAME!=\"DEFAULT\"");
+  q=new RDSqlQuery("select NAME from STATIONS where NAME!=\"DEFAULT\"");
   while(q->next()) {
     edit_station_box->insertItem(q->value(0).toString());
     if(edit_recording->station()==q->value(0).toString()) {
@@ -417,6 +443,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
     edit_normalize_spin->setValue(rdlibrary_conf->ripperLevel()/100);
   }
   normalizeToggledData(edit_normalize_box->isChecked());
+  edit_metadata_box->setChecked(edit_recording->enableMetadata());
   edit_mon_button->setChecked(edit_recording->mon());
   edit_tue_button->setChecked(edit_recording->tue());
   edit_wed_button->setChecked(edit_recording->wed());
@@ -424,6 +451,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_fri_button->setChecked(edit_recording->fri());
   edit_sat_button->setChecked(edit_recording->sat());
   edit_sun_button->setChecked(edit_recording->sun());
+  edit_eventoffset_spin->setValue(edit_recording->eventdateOffset());
   edit_oneshot_box->setChecked(edit_recording->oneShot());
 }
 
@@ -439,7 +467,7 @@ EditDownload::~EditDownload()
 
 QSize EditDownload::sizeHint() const
 {
-  return QSize(520,383);
+  return QSize(520,432);
 } 
 
 
@@ -453,7 +481,8 @@ void EditDownload::urlChangedData(const QString &str)
 {
   QUrl url(str);
   QString protocol=url.protocol();
-  if((protocol=="ftp")||(protocol=="http")||(protocol=="smb")) {
+  if((protocol=="ftp")||(protocol=="http")||(protocol=="file")||
+     (protocol=="scp")||(protocol=="sftp")) {
     edit_username_label->setEnabled(true);
     edit_username_edit->setEnabled(true);
     edit_password_label->setEnabled(true);
@@ -472,8 +501,9 @@ void EditDownload::selectCartData()
 {
   QString str;
 
-  RDCutDialog *cut=new RDCutDialog(&edit_cutname,edit_filter,NULL,
-				   catch_user->name(),false,true);
+  RDCutDialog *cut=new RDCutDialog(&edit_cutname,rdstation_conf,catch_system,
+				   edit_filter,NULL,NULL,catch_user->name(),
+				   false,true);
   switch(cut->exec()) {
       case 0:
 	edit_description_edit->setText(RDCutPath(edit_cutname));
@@ -527,14 +557,14 @@ void EditDownload::okData()
   RDUrl url(edit_url_edit->text());
   QString protocol=url.protocol();
   if((protocol!="ftp")&&(protocol!="http")&&(protocol!="https")&&
-     (protocol!="smb")&&(protocol!="file")) {
+     (protocol!="file")&&(protocol!="scp")&&(protocol!="sftp")) {
     QMessageBox::warning(this,
 			 tr("Invalid URL"),tr("Unsupported URL protocol!"));
     return;
   }
-  if((protocol=="smb")&&((!url.validSmbShare())||(url.smbPath()=="/"))) {
-    QMessageBox::warning(this,
-			 tr("Invalid URL"),tr("The URL is invalid!"));
+  if((protocol=="file")&&(edit_username_edit->text().isEmpty())) {
+    QMessageBox::warning(this,tr("Missing Username"),
+			 tr("You must specify a username!"));
     return;
   }
   if(!CheckEvent(false)) {
@@ -557,7 +587,7 @@ void EditDownload::paintEvent(QPaintEvent *e)
 {
   QPainter *p=new QPainter(this);
   p->setPen(QColor(black));
-  p->drawRect(10,237,sizeHint().width()-20,62);
+  p->drawRect(10,262,sizeHint().width()-20,62);
   p->end();
 }
 
@@ -607,6 +637,7 @@ void EditDownload::Save()
   edit_recording->setUrl(edit_url_edit->text());
   edit_recording->setUrlUsername(edit_username_edit->text());
   edit_recording->setUrlPassword(edit_password_edit->text());
+  edit_recording->setEnableMetadata(edit_metadata_box->isChecked());
   edit_recording->setMon(edit_mon_button->isChecked());
   edit_recording->setTue(edit_tue_button->isChecked());
   edit_recording->setWed(edit_wed_button->isChecked());
@@ -614,6 +645,7 @@ void EditDownload::Save()
   edit_recording->setFri(edit_fri_button->isChecked());
   edit_recording->setSat(edit_sat_button->isChecked());
   edit_recording->setSun(edit_sun_button->isChecked());
+  edit_recording->setEventdateOffset(edit_eventoffset_spin->value());
   edit_recording->setOneShot(edit_oneshot_box->isChecked());
 }
 
@@ -655,7 +687,7 @@ bool EditDownload::CheckEvent(bool include_myself)
   if(!include_myself) {
     sql+=QString().sprintf("&&(ID!=%d)",edit_recording->id());
   }
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   bool res=!q->first();
   delete q;
 
