@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_cart.cpp,v 1.74.2.3 2013/12/16 02:50:46 cvs Exp $
+//      $Id: edit_cart.cpp,v 1.74.2.7.2.2 2014/05/28 21:21:41 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,8 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <vector>
+
 #include <qbitmap.h>
 #include <unistd.h>
 #include <qdialog.h>
@@ -34,6 +36,7 @@
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
 #include <qtooltip.h>
+#include <qvalidator.h>
 
 #include <rddb.h>
 #include <rd.h>
@@ -50,12 +53,13 @@
 #include <edit_schedulercodes.h>
 #include <edit_notes.h>
 
-EditCart::EditCart(unsigned number,QString *path,bool new_cart,
+EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
 		   QWidget *parent,const char *name,QListView *lib_cart_list)
   : QDialog(parent,name,true)
 {
   bool modification_allowed;
   rdcart_cart=NULL;
+  rdcart_profile_rip=profile_rip;
 
   rdcart_new_cart=new_cart;
   sched_codes="";
@@ -312,9 +316,12 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   //
   // Cart Origination Year
   //
+  QIntValidator *val=new QIntValidator(this);
+  val->setBottom(1);
   rdcart_controls.year_edit=new QLineEdit(this,"rdcart_year_edit");
   rdcart_controls.year_edit->setGeometry(135,110,50,21);
   rdcart_controls.year_edit->setFont(line_edit_font);
+  rdcart_controls.year_edit->setValidator(val);
   rdcart_controls.year_edit->setMaxLength(255);
   QLabel *rdcart_year_label=new QLabel(rdcart_controls.year_edit,
 					     tr("&Year Released:"),this,
@@ -372,7 +379,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.bpm_spin=new QSpinBox(this);
   rdcart_controls.bpm_spin->setGeometry(515,135,100,21);
   rdcart_controls.bpm_spin->setFont(line_edit_font);
-  rdcart_controls.bpm_spin->setRange(0,200);
+  rdcart_controls.bpm_spin->setRange(0,300);
   rdcart_controls.bpm_spin->setSpecialValueText(tr("Unknown"));
   QLabel *rdcart_bpm_label=
     new QLabel(rdcart_controls.bpm_spin,tr("&Beats per Minute:"),this);
@@ -504,6 +511,38 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_syncronous_label->setAlignment(AlignLeft|ShowPrefix);
   rdcart_syncronous_label->hide();
 
+  //
+  // Use Event Length Policy
+  //
+  rdcart_use_event_length_box=new QCheckBox(this);
+  rdcart_use_event_length_box->setGeometry(330,351,15,15);
+  connect(rdcart_use_event_length_box,SIGNAL(toggled(bool)),
+	  this,SLOT(asyncronousToggledData(bool)));
+  rdcart_use_event_length_box->hide();
+  QLabel *rdcart_use_event_length_label=
+    new QLabel(rdcart_use_event_length_box,
+	       tr("Use Event Length for Now && Next Updates"),this);
+  rdcart_use_event_length_label->setGeometry(350,351,sizeHint().width()-350,19);
+  rdcart_use_event_length_label->setFont(button_font);
+  rdcart_use_event_length_label->setAlignment(AlignLeft|ShowPrefix);
+  rdcart_use_event_length_label->hide();
+
+  //
+  // Cut Scheduling Policy
+  //
+  rdcart_cut_sched_box=new QComboBox(this);
+  rdcart_cut_sched_box->setGeometry(135,348,150,21);
+  rdcart_cut_sched_box->insertItem(tr("By Specified Order"));
+  rdcart_cut_sched_box->insertItem(tr("By Weight"));
+  rdcart_cut_sched_edit=new QLineEdit(this);
+  rdcart_cut_sched_edit->setGeometry(135,348,150,21);
+  rdcart_cut_sched_edit->hide();
+  QLabel *rdcart_cut_sched_label=
+    new QLabel(rdcart_cut_sched_box,tr("Schedule Cuts")+":",this);
+  rdcart_cut_sched_label->setGeometry(10,348,120,19);
+  rdcart_cut_sched_label->setFont(button_font);
+  rdcart_cut_sched_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Notes Button
   //
@@ -532,12 +571,14 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
       case RDCart::Audio:
 	rdcart_audio_cart=new AudioCart(&rdcart_controls,rdcart_cart,
 					rdcart_import_path,new_cart,
-					this,"rdcart_audio_cart");
+					rdcart_profile_rip,this);
 	rdcart_audio_cart->
 	  setGeometry(0,378,rdcart_audio_cart->sizeHint().width(),
 		      rdcart_audio_cart->sizeHint().height());
 	connect(rdcart_audio_cart,SIGNAL(cartDataChanged()),
 		this,SLOT(cartDataChangedData()));
+	connect(rdcart_cut_sched_box,SIGNAL(activated(int)),
+		rdcart_audio_cart,SLOT(changeCutScheduling(int)));
 	rdcart_macro_cart=NULL;
 	break;
 	
@@ -552,7 +593,9 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
 	rdcart_controls.enforce_length_box->setDisabled(true);
 	rdcart_enforce_length_label->setDisabled(true);
 	rdcart_syncronous_box->show();
+	rdcart_use_event_length_box->show();
 	rdcart_syncronous_label->show();
+	rdcart_use_event_length_label->show();
 	break;
 	
       default:
@@ -606,6 +649,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
     switch(rdcart_cart->type()) {
 	case RDCart::Audio:
 	  rdcart_type_edit->setText(tr("AUDIO"));
+	  rdcart_audio_cart->changeCutScheduling(rdcart_cart->useWeighting());
 	  break;
 	  
 	case RDCart::Macro:
@@ -622,8 +666,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
     forcedLengthData(rdcart_controls.enforce_length_box->isChecked());
     if(lib_cart_list_edit==NULL) {
       rdcart_average_length_edit->
-	setText(QString().sprintf("%s",
-				  (const char *)RDGetTimeLength(rdcart_cart->averageLength())));
+	setText(RDGetTimeLength(rdcart_cart->averageLength()));
     }
     rdcart_controls.forced_length_edit->
       setTime(QTime().addMSecs(rdcart_cart->forcedLength()));
@@ -648,8 +691,9 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
     else {
       rdcart_end_date_edit->setText(tr("TFN"));
     }
-    if(!rdcart_cart->year().isNull()) {
-      rdcart_controls.year_edit->setText(rdcart_cart->year().toString("yyyy"));
+    if(rdcart_cart->year()>0) {
+      rdcart_controls.year_edit->
+	setText(QString().sprintf("%d",rdcart_cart->year()));
     }
     sched_codes=rdcart_cart->schedCodes();
     rdcart_controls.artist_edit->setText(rdcart_cart->artist());
@@ -668,6 +712,10 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
       setText(RDCart::usageText((RDCart::UsageCode)rdcart_usage_box->
 				currentItem()));
     rdcart_syncronous_box->setChecked(rdcart_cart->asyncronous());
+    rdcart_use_event_length_box->
+      setChecked(rdcart_cart->useEventLength());
+    rdcart_cut_sched_box->setCurrentItem(rdcart_cart->useWeighting());
+    rdcart_cut_sched_edit->setText(rdcart_cut_sched_box->currentText());
   }
   else {//multi edit
     if(rdcart_group_box->count() == 0) {
@@ -691,6 +739,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
     rdcart_usage_box->hide();
   }
   rdcart_syncronous_box->setEnabled(modification_allowed);
+  rdcart_use_event_length_box->setEnabled(modification_allowed);
   rdcart_controls.title_edit->setReadOnly(!modification_allowed);
   rdcart_controls.artist_edit->setReadOnly(!modification_allowed);
   rdcart_controls.song_id_edit->setReadOnly(!modification_allowed);
@@ -725,6 +774,14 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
       setRange(rdcart_cart->beatsPerMinute(),rdcart_cart->beatsPerMinute());
     rdcart_controls.forced_length_edit->hide();
     rdcart_forced_length_ledit->show();
+    if(rdcart_cart->type()==RDCart::Audio) {
+      rdcart_cut_sched_box->hide();
+      rdcart_cut_sched_edit->show();
+    }
+  }
+  if(rdcart_cart->type()==RDCart::Macro) {
+    rdcart_cut_sched_box->hide();
+    rdcart_cut_sched_label->hide();
   }
 }
 
@@ -773,7 +830,6 @@ void EditCart::lengthChangedData(unsigned len)
 
 void EditCart::okData()
 {
-  int year;
   QListViewItemIterator *it;
   RDCart *rdcart_cart_medit;
   RDSystem *system;
@@ -788,10 +844,9 @@ void EditCart::okData()
     }
     system=new RDSystem();
     if(!system->allowDuplicateCartTitles()) {
-      sql=QString().sprintf("select NUMBER from CART \
-                             where (TITLE=\"%s\")&&(NUMBER!=%u)",
-	  (const char *)RDEscapeString(rdcart_controls.title_edit->text()),
-	  rdcart_cart->number());
+      sql=QString("select NUMBER from CART where ")+
+	"(TITLE=\""+RDEscapeString(rdcart_controls.title_edit->text())+"\") &&"+
+	QString().sprintf("(NUMBER!=%u)",rdcart_cart->number());
       q=new RDSqlQuery(sql);
       if(q->first()) {
 	QMessageBox::warning(this,tr("Duplicate Title"),
@@ -816,6 +871,35 @@ void EditCart::okData()
 	}
       }
     }
+    if(rdcart_cut_sched_box->currentItem()==0) {
+      std::vector<int> play_orders;
+      std::vector<int> order_duplicates;
+      sql=QString("select PLAY_ORDER from CUTS where ")+
+	QString().sprintf("CART_NUMBER=%u",rdcart_cart->number());
+      q=new RDSqlQuery(sql);
+      while(q->next()) {
+	play_orders.push_back(q->value(0).toInt());
+      }
+      delete q;
+      for(unsigned i=0;i<play_orders.size();i++) {
+	for(unsigned j=i;j<play_orders.size();j++) {
+	  if((i!=j)&&(play_orders[i]==play_orders[j])) {
+	    order_duplicates.push_back(play_orders[j]);
+	  }
+	}
+      }
+      if(order_duplicates.size()>0) {
+	QString msg=
+	  tr("The following cut order values are assigned more than once")+
+	  ":\n";
+	for(unsigned i=0;i<order_duplicates.size();i++) {
+	  msg+=QString().sprintf("%d, ",order_duplicates[i]);
+	}
+	msg=msg.left(msg.length()-2)+".";
+	QMessageBox::warning(this,"RDLibrary - "+tr("Duplicate Cut Order"),msg);
+	return;
+      }
+    }
     rdcart_cart->setGroupName(rdcart_group_box->currentText());
     rdcart_cart->calculateAverageLength(&rdcart_length_deviation);
     rdcart_cart->setLengthDeviation(rdcart_length_deviation);
@@ -836,12 +920,11 @@ void EditCart::okData()
     }
     rdcart_cart->setPreservePitch(rdcart_preserve_pitch_button->isChecked());
     rdcart_cart->setTitle(rdcart_controls.title_edit->text());
-    if(sscanf((const char *)rdcart_controls.year_edit->text(),
-	      "%d",&year)==1) {
-      rdcart_cart->setYear(QDate(year,1,1));
+    if(rdcart_controls.year_edit->text().toInt()==0) {
+      rdcart_cart->setYear();
     }
     else {
-      rdcart_cart->setYear();
+      rdcart_cart->setYear(rdcart_controls.year_edit->text().toInt());
     }
     rdcart_cart->setSchedCodes(sched_codes);
     rdcart_cart->setArtist(rdcart_controls.artist_edit->text());
@@ -860,54 +943,72 @@ void EditCart::okData()
     if(rdcart_cart->type()==RDCart::Macro) {
       rdcart_macro_cart->save();
       rdcart_cart->setAsyncronous(rdcart_syncronous_box->isChecked());
+      rdcart_cart->setUseEventLength(rdcart_use_event_length_box->isChecked());
+    }
+    else {
+      rdcart_cart->setUseWeighting(rdcart_cut_sched_box->currentItem());
     }
   }
   else {  // Multi Edit
     it=new QListViewItemIterator(lib_cart_list_edit);
     while(it->current()) {
-      if (it->current()->isSelected()) {  
+      if(it->current()->isSelected()) {  
         RDListViewItem *item=(RDListViewItem *)it->current();
-        if(item->text(19).isEmpty()) {
-	  
+        if(item->text(21).isEmpty()) {
+ 
           rdcart_cart_medit=new RDCart(item->text(1).toUInt());
 	  
-          if(!rdcart_group_box->currentText().stripWhiteSpace().isEmpty())
+          if(!rdcart_group_box->currentText().stripWhiteSpace().isEmpty()) {
 	    rdcart_cart_medit->setGroupName(rdcart_group_box->currentText());
-          if(!rdcart_controls.title_edit->text().stripWhiteSpace().isEmpty())
-            rdcart_cart_medit->setTitle(rdcart_controls.title_edit->text());
-          if(!rdcart_controls.year_edit->text().stripWhiteSpace().isEmpty()) {
-            if(sscanf((const char *)rdcart_controls.year_edit->text(),
-		      "%d",&year)==1) {
-              rdcart_cart_medit->setYear(QDate(year,1,1));
-            }
-            else {
-              rdcart_cart->setYear();
-            }
 	  }
-          if(!rdcart_controls.artist_edit->text().stripWhiteSpace().isEmpty())
+          if(!rdcart_controls.title_edit->text().stripWhiteSpace().isEmpty()) {
+            rdcart_cart_medit->setTitle(rdcart_controls.title_edit->text());
+	  }
+	  rdcart_cart_medit->setYear(rdcart_controls.year_edit->text().toInt());
+          if(!rdcart_controls.artist_edit->text().stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->setArtist(rdcart_controls.artist_edit->text());
-          if(!rdcart_controls.album_edit->text().stripWhiteSpace().isEmpty())
+	  }
+          if(!rdcart_controls.album_edit->text().stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->setAlbum(rdcart_controls.album_edit->text());
-          if(!rdcart_controls.label_edit->text().stripWhiteSpace().isEmpty())
+	  }
+          if(!rdcart_controls.label_edit->text().stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->setLabel(rdcart_controls.label_edit->text());
-          if(!rdcart_controls.client_edit->text().stripWhiteSpace().isEmpty())
+	  }
+          if(!rdcart_controls.client_edit->text().stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->setClient(rdcart_controls.client_edit->text());
-          if(!rdcart_controls.agency_edit->text().stripWhiteSpace().isEmpty())
+	  }
+          if(!rdcart_controls.agency_edit->text().stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->setAgency(rdcart_controls.agency_edit->text());
+	  }
+          if(!rdcart_controls.song_id_edit->
+	     text().stripWhiteSpace().isEmpty()) {
+            rdcart_cart_medit->
+	      setSongId(rdcart_controls.song_id_edit->text());
+	  }
           if(!rdcart_controls.publisher_edit->text().stripWhiteSpace().
-	     isEmpty())
+	     isEmpty()) {
             rdcart_cart_medit->
 	      setPublisher(rdcart_controls.publisher_edit->text());
-          if(!rdcart_controls.composer_edit->text().stripWhiteSpace().isEmpty())
+	  }
+          if(!rdcart_controls.composer_edit->
+	     text().stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->
 	      setComposer(rdcart_controls.composer_edit->text());
+	  }
+          if(!rdcart_controls.conductor_edit->text().
+	     stripWhiteSpace().isEmpty()) {
+            rdcart_cart_medit->
+	      setConductor(rdcart_controls.conductor_edit->text());
+	  }
           if(!rdcart_controls.user_defined_edit->text().
-	     stripWhiteSpace().isEmpty())
+	     stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->
 	      setUserDefined(rdcart_controls.user_defined_edit->text());
-          if(!rdcart_usage_box->currentText().stripWhiteSpace().isEmpty())
-            rdcart_cart_medit->
-	      setUsageCode((RDCart::UsageCode)(rdcart_usage_box->currentItem()-1));
+	  }
+          if(!rdcart_usage_box->currentText().stripWhiteSpace().isEmpty()) {
+            rdcart_cart_medit->setUsageCode((RDCart::UsageCode)
+				    (rdcart_usage_box->currentItem()-1));
+	  }
           rdcart_cart_medit->updateSchedCodes(add_codes,remove_codes);
 	  delete rdcart_cart_medit; 
         }
@@ -966,8 +1067,7 @@ void EditCart::cartDataChangedData()
 {
   if(!rdcart_controls.enforce_length_box->isChecked()) {
     rdcart_average_length_edit->
-      setText(QString().sprintf("%s",
-	  (const char *)RDGetTimeLength(rdcart_cart->calculateAverageLength())));
+      setText(RDGetTimeLength(rdcart_cart->calculateAverageLength()));
   }
 }
 
@@ -1022,10 +1122,10 @@ void EditCart::schedCodesData()
 
 void EditCart::PopulateGroupList()
 {
-  QString sql=
-    QString().sprintf("select GROUP_NAME from USER_PERMS \
-                       where USER_NAME=\"%s\" order by GROUP_NAME",
-		      (const char *)lib_user->name());
+  QString sql=QString("select GROUP_NAME from USER_PERMS where ")+
+    "USER_NAME=\""+RDEscapeString(lib_user->name())+"\" "+
+    "order by GROUP_NAME";
+
   RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     rdcart_group_box->insertItem(q->value(0).toString());
