@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_perms.cpp,v 1.7 2007/10/04 20:53:39 dmills Exp $
+//      $Id: edit_perms.cpp,v 1.10.8.1 2012/04/23 17:22:47 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -107,6 +107,7 @@ EditPerms::EditPerms(QString object_name,ObjectType type,
 	object_type="CLOCK";
 	break;
   }
+  // FIXME: should this be filtered based on the user if usersec is enabled?
   sql=QString().sprintf("select SERVICE_NAME from %s_PERMS \
                          where %s_NAME=\"%s\"",
 			(const char *)object_type,
@@ -198,3 +199,9 @@ void EditPerms::cancelData()
 {
   done(-1);
 }
+
+
+void EditPerms::closeEvent(QCloseEvent *e)
+{
+  cancelData();
+}
