@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: btss124.h,v 1.3 2007/02/14 21:57:04 fredg Exp $
+//      $Id: btss124.h,v 1.9 2010/08/03 23:39:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,38 +23,33 @@
 #ifndef BTSS124_H
 #define BTSS124_H
 
-#include <qobject.h>
-
 #include <rd.h>
 #include <rdmatrix.h>
 #include <rdmacro.h>
 #include <rdtty.h>
 
+#include <switcher.h>
+
 #define BTSS124_UNIT_ID 0
 
-
-class BtSs124 : public QObject
+class BtSs124 : public Switcher
 {
  Q_OBJECT
  public:
   BtSs124(RDMatrix *matrix,QObject *parent=0,const char *name=0);
   ~BtSs124();
+  RDMatrix::Type type();
+  unsigned gpiQuantity();
+  unsigned gpoQuantity();
+  bool primaryTtyActive();
+  bool secondaryTtyActive();
   void processCommand(RDMacro *cmd);
 
- public slots:
-  void processStatus();
-
- signals:
-  void rmlEcho(RDMacro *cmd);
-  void gpiChanged(int matrix,int line,bool state);
-
  private:
-  RTTYDevice *bt_device;
+  RDTTYDevice *bt_device;
   int bt_matrix;
   int bt_inputs;
   int bt_outputs;
-  int bt_gpis;
-  int bt_gpos;
 };
 
 
