@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddbcheck.cpp,v 1.18.4.1 2013/11/13 23:36:39 cvs Exp $
+//      $Id: rddbcheck.cpp,v 1.18.4.1.2.1 2014/06/02 18:52:22 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -37,6 +37,7 @@
 #include <rddbcheck.h>
 #include <rdcart.h>
 #include <rdlog.h>
+#include <rdclock.h>
 #include <rdcreate_log.h>
 #include <rdescape_string.h>
 #include <rdwavefile.h>
@@ -196,6 +197,13 @@ MainObject::MainObject(QObject *parent,const char *name)
   CheckOrphanedTables();
   printf("done.\n\n");
 
+  //
+  // Check for stale reservations
+  //
+  printf("Checking for stale cart reservations...\n");
+  CheckPendingCarts();
+  printf("done.\n\n");
+
   //
   // Check for orphaned carts
   //
@@ -276,20 +284,16 @@ void MainObject::CheckClocks()
   QSqlQuery *q1;
   QSqlQuery *q2;
   QSqlQuery *q3;
-  QString clockname;
   QString eventname;
 
   sql="select NAME from CLOCKS";
   q=new QSqlQuery(sql);
   while(q->next()) {
-    clockname=q->value(0).toString();
-    clockname.replace(" ","_");
-
     //
     // Check the CLK Table
     //
-    sql=QString().sprintf ("select EVENT_NAME,ID from %s_CLK",
-			   (const char *)clockname);
+    sql=QString("select EVENT_NAME,ID from ")+
+      RDClock::tableName(q->value(0).toString());
     q1=new QSqlQuery(sql);
     if(q1->isActive()) {
       //
@@ -302,15 +306,14 @@ void MainObject::CheckClocks()
 	if(q2->first()) {
 	  if(q1->value(0)!=q2->value(0)) {  // Make sure the cases match!
 	    printf("  Clock %s's linkage to event %s is broken -- fix (y/N)? ",
-		   (const char *)clockname,
+		   (const char *)q->value(0).toString(),
 		   (const char *)q2->value(0).toString());
 	    fflush(NULL);
 	    if(UserResponse()) {
-	      sql=QString().sprintf("update %s_CLK set EVENT_NAME=\"%s\"\
-                                     where ID=%d",
-				    (const char *)clockname,
-				    (const char *)q2->value(0).toString(),
-				    q1->value(1).toInt());
+	      sql=QString("update ")+
+		RDClock::tableName(q->value(0).toString())+
+		" set EVENT_NAME=\""+RDEscapeString(q2->value(0).toString())+
+		"\""+QString().sprintf(" where ID=%d",q1->value(1).toInt());
 	      q3=new QSqlQuery(sql);
 	      delete q3;
 	    }
@@ -324,7 +327,7 @@ void MainObject::CheckClocks()
 	     (const char *)q->value(0).toString());
       fflush(NULL);
       if(UserResponse()) {
-	sql=RDCreateClockTableSql(clockname);
+	sql=RDCreateClockTableSql(RDClock::tableName(q->value(0).toString()));
 	q2=new QSqlQuery(sql);
 	delete q2;
       }
@@ -332,7 +335,6 @@ void MainObject::CheckClocks()
     delete q1;
   }
   delete q;
-
 }
 
 
@@ -484,6 +486,30 @@ void MainObject::CheckCutCounts()
 }
 
 
+void MainObject::CheckPendingCarts()
+{
+  QString sql;
+  QSqlQuery *q;
+  QDateTime now(QDate::currentDate(),QTime::currentTime());
+
+  sql=QString("select NUMBER from CART where ")+
+    "(PENDING_STATION is not null)&&"+
+    "(PENDING_DATETIME<\""+now.addDays(-1).
+    toString("yyyy-MM-dd hh:mm:ss")+"\")";
+  printf("SQL: %s\n",(const char *)sql);
+  q=new QSqlQuery(sql);
+  while(q->next()) {
+    printf("  Cart %06u has stale reservation, delete cart(y/N)?",
+	   q->value(0).toUInt());
+    if(UserResponse()) {
+      RDCart::removeCart(q->value(0).toUInt(),check_station,check_user,
+			 rdconfig);
+    }
+  }
+  delete q;
+}
+
+
 void MainObject::CheckOrphanedCarts()
 {
   QString sql;
